@@ -60,7 +60,7 @@ fn main() {
         );
         ap.add_option(
             &["-V", "--version"],
-            Print((&"ustat version 0.2.1"[..]).to_string()),
+            Print((&"ustat version 0.2.2"[..]).to_string()),
             "Show version",
         );
         ap.parse_args_or_exit();
@@ -72,6 +72,10 @@ fn main() {
     // Hnadle the case where there are multiple different columns.
     if input_files.len() == 0 && columns.len() <= 1 {
         columns.push(columns[0]);
+    } else if input_files.len() != columns.len() && columns.len() == 1 {
+        while input_files.len() > columns.len() {
+            columns.push(columns[0]);
+        }
     } else if input_files.len() != columns.len() {
         panic!("{} column indices passed, but there are {} files. Pass either 1 column index, or a column for each input file.", columns.len(), input_files.len());
     }
